==> igloo_0_1_8.zip: igloo_0_1_8/igloo/language/1/barnraiser_01/spl_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

//HDR
$lang['hdr_welcome'] = 						"welcome";
$lang['hdr_start'] = 						"getting started";
$lang['hdr_credits'] = 						"credits";
$lang['hdr_about_igloo'] = 					"about Igloo";
$lang['hdr_man'] = 							"guide for this software";
$lang['hdr_login'] = 						"login";
$lang['hdr_password'] = 					"forgotten password?";


// FORM
$lang['form_user_homepage'] = 				"don't show this page again";


//BODY TEXT
$lang['txt_public_introduction'] = 			"<h3>Welcome to your instance of Igloo</h3><p>Put a public introduction here.</p>";
$lang['txt_introduction'] = 				"<h3>Welcome to your instance of Igloo</h3><p>Put a registered user introduction here.</p>";
$lang['txt_start'] = 						"Place some texts here to start people with using your instance of Igloo.";
$lang['txt_welcome'] = 						"welcome";
$lang['txt_credits'] = 						"Igloo was conceived by Tom Calthrop, founder of Barnraiser and 'Igloo' project maintainer. Many thanks to the developers who have given time, energy and expertise to the Igloo project!";
$lang['txt_about_igloo'] = 					"Barnraiser is an organisation dedicated to giving people the tools they need to share knowledge and advance society through social software.<br /><p>As part of their mission they maintain 'Igloo', the software platform that this community is build upon.<br /></p><p>Visit Barnraiser at <a href=\"http://www.barnraiser.org/\" target=\"_new\">www.barnraiser.org</a> to find out more about their work.<br /></p>";
$lang['txt_email'] = 						"your email address";
$lang['txt_password'] = 					"your password";
$lang['txt_new_password'] = 				"If you have forgotten your password you can <a href =\"new_password.php\">get a new password here</a>.";
$lang['txt_login_note'] = 					"You will remain logged in until you press 'logoff' or exit the browser.";

?>

==> igloo_0_1_9.zip: igloo_0_1_9/igloo/language/1/barnraiser_01/spl_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

//HDR
$lang['hdr_welcome'] = 						"welcome";
$lang['hdr_start'] = 						"getting started";
$lang['hdr_credits'] = 						"credits";
$lang['hdr_about_igloo'] = 					"about Igloo";
$lang['hdr_man'] = 							"guide for this software";
$lang['hdr_login'] = 						"login";
$lang['hdr_password'] = 					"forgotten password?";
$lang['hdr_dormant'] = 						"your account is dormant";
$lang['hdr_activate'] = 					"re-activate your account";


//SUBMIT BUTTON
$lang['sub_send'] = 						"re-activate";


// FORM
$lang['form_user_homepage'] = 				"don't show this page again";


//BODY TEXT
$lang['txt_public_introduction'] = 			"<h3>Welcome to your instance of Igloo</h3><p>Put a public introduction here.</p>";
$lang['txt_introduction'] = 				"<h3>Welcome to your instance of Igloo</h3><p>Put a registered user introduction here.</p>";
$lang['txt_start'] = 						"Place some texts here to start people with using your instance of Igloo.";
$lang['txt_welcome'] = 						"welcome";
$lang['txt_credits'] = 						"Igloo was conceived by Tom Calthrop, founder of Barnraiser and 'Igloo' project maintainer. Many thanks to the developers who have given time, energy and expertise to the Igloo project!";
$lang['txt_about_igloo'] = 					"Barnraiser is an organisation dedicated to giving people the tools they need to share knowledge and advance society through social software.<br /><p>As part of their mission they maintain 'Igloo', the software platform that this community is build upon.<br /></p><p>Visit Barnraiser at <a href=\"http://www.barnraiser.org/\" target=\"_new\">www.barnraiser.org</a> to find out more about their work.<br /></p>";
$lang['txt_email'] = 						"your email address";
$lang['txt_password'] = 					"your password";
$lang['txt_new_password'] = 				"If you have forgotten your password you can <a href =\"new_password.php\">get a new password here</a>.";
$lang['txt_login_note'] = 					"You will remain logged in until you press 'logoff' or exit the browser.";
$lang['txt_intro_dormant'] = 				"Your account is set to 'dormant' which mean that you have 'paused' your account. Maybe you did this because you want on holiday or maybe it is because you changed your email. Just type in your email and date of birth and we will re-active your account by sending you an email with a new password in it.";
$lang['txt_dob'] = 							"your date of birth";
$lang['txt_email'] = 						"your email address";
$lang['txt_captcha'] = 						"Captcha";
$lang['txt_captcha_intro'] = 				"Please type the characters that you see below.";
$lang['txt_email_subject_activate'] = 		"Your new password";

?>
